@@ -444,6 +444,9 @@ _getopt_initialize (argc, argv, optstring)
     }
   else
     nonoption_flags_len = 0;
+#else
+  (void)argc;
+  (void)argv;
 #endif
 
   return optstring;
